ghcitui-0.4.1.0: A Terminal User Interface (TUI) for GHCi
Safe HaskellSafe-Inferred
LanguageHaskell2010

Ghcitui.Util

Synopsis

Documentation

showT :: Show a => a -> Text Source #

show but to Text.

splitBy Source #

Arguments

:: Text

Delimeter.

-> Text

Text to split on.

-> [Text] 

Split text based on a delimiter.

linesToText :: [String] -> Text Source #

Convert Strings to Text.

clamp Source #

Arguments

:: Ord a 
=> (a, a)

The minimum and maximum (inclusive).

-> a

Value to clamp.

-> a

Result.

getNumDigits :: Integral a => a -> Int Source #

Return the number of digits in a given integral

formatDigits Source #

Arguments

:: Int

Number of spaces

-> Int

Number to format digits of

-> Text

Formatted Text

Format digits into a string with padding.

dropMiddleToFitText Source #

Arguments

:: Int

Maximum length to trim to.

-> Text

Text to shorten.

-> Text

Result.

Remove the inner characters of a Text to fit within a maximum width.