| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Ghcitui.Util
Documentation
Split text based on a delimiter.
linesToText :: [String] -> Text Source #
Convert Strings to Text.
Arguments
| :: Ord a | |
| => (a, a) | The minimum and maximum (inclusive). |
| -> a | Value to clamp. |
| -> a | Result. |
getNumDigits :: Integral a => a -> Int Source #
Return the number of digits in a given integral
Format digits into a string with padding.
Remove the inner characters of a Text to fit within a maximum width.
revealNewlines :: Text -> Text Source #